pub enum LifetimeMutability {
Mutable,
Shared,
Unknown,
}Expand description
The nature of locations where a given lifetime parameter is used. If this lifetime ever flows
to be used as the lifetime of a mutable reference &'a mut then we consider it mutable.
Variants
Mutable
A lifetime that is used for a mutable reference.
A lifetime used only in shared references.
Unknown
A lifetime for which we couldn’t/didn’t compute mutability.
Implementations
Sourceimpl LifetimeMutability
impl LifetimeMutability
pub fn is_mutable(&self) -> bool
pub fn is_unknown(&self) -> bool