pub enum PtrMetadata {
None,
Length,
VTable(TypeDeclRef),
InheritFrom(Ty),
}Expand description
The metadata stored in a pointer. That’s the information stored in pointers alongside
their address. It’s empty for Sized types, and interesting for unsized
aka dynamically-sized types.
Variants
None
Types that need no metadata, namely T: Sized types.
Length
Metadata for [T] and str, and user-defined types
that directly or indirectly contain one of the two.
Of type usize.
Notably, length for [T] denotes the number of elements in the slice.
While for str it denotes the number of bytes in the string.
VTable(TypeDeclRef)
Metadata for dyn Trait, referring to the vtable struct. Has type &'static vtable
InheritFrom(Ty)
Unknown due to generics, but will inherit from the given type.
This is consistent with <Ty as Pointee>::Metadata.
Of type TyKind::Metadata(Ty).
Implementations