pub struct Layout {
pub size: Option<ByteCount>,
pub align: Option<ByteCount>,
pub discriminator: Option<Discriminator>,
pub uninhabited: bool,
pub variant_layouts: IndexVec<VariantId, Option<VariantLayout>>,
pub repr: ReprOptions,
}Expand description
Simplified type layout information.
Does not include information about niches. If the type does not have a fully known layout (e.g. it is ?Sized) some of the layout parts are not available.
Fields
size: Option<ByteCount>The size of the type in bytes.
align: Option<ByteCount>The alignment, in bytes.
discriminator: Option<Discriminator>Decision tree that determines the active variant by reading memory. Only Some for enums.
uninhabited: boolWhether the type is uninhabited, i.e. has any valid value at all.
Note that uninhabited types can have arbitrary layouts: (u32, !) has space for the u32
and enum E2 { A, B(!), C(i32, !) } may have space for a discriminant.
variant_layouts: IndexVec<VariantId, Option<VariantLayout>>Map from VariantId to the corresponding field layouts. Some variants don’t have a
meaningful layout due to being uninhabited (though an uninhabited variant may have a
layout). Structs and unions are modeled as having exactly one variant.
repr: ReprOptionsThe representation options of this type declaration as annotated by the user.
Implementations